@@ -1,6 +1,6 @@
 /*
     This file is part of the FElt finite element analysis package.
-    Copyright (C) 1993-1997 Jason I. Gobat and Darren C. Atkinson
+    Copyright (C) 1993-2000 Jason I. Gobat and Darren C. Atkinson
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1136,17 +1136,32 @@ int ElementSetup (element, mass_mode)
 int ElementStresses ( )
 {
     Element	*e;
+    Node	*n;
     unsigned	 ne;
-    int		 i, status;
+    unsigned	 nn;
+    int		 i, j, status;
  
     e = problem.elements;
     ne = problem.num_elements;
+    n = problem.nodes;
+    nn = problem.num_nodes;
  
     status = 0;
 
     for (i = 1 ; i <= ne ; i++)
 	status += e [i] -> definition -> stress (e [i]);
 
+	/*
+	 * compute the nodally averaged stresses
+	 */
+
+    for (i = 1 ; i <= nn ; i++) {
+       if (n [i] -> stress && n [i] -> numelts) {
+          for (j = 1 ; j <= 10 ; j++)
+             n [i] -> stress [j] /= n [i] -> numelts;
+       }
+    }
+
     return status;
 }
 
