@@ -1,6 +1,6 @@
 /*
     This file is part of the FElt finite element analysis package.
-    Copyright (C) 1993-1997 Jason I. Gobat and Darren C. Atkinson
+    Copyright (C) 1993-2000 Jason I. Gobat and Darren C. Atkinson
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -662,7 +662,7 @@ SolutionDialog SolutionDialogCreate (parent, name, title)
 
     XtSetArg (args [0], XtNdepth, &depth);
     XtGetValues (parent, args, 1);
-    if (depth != 8) {
+    if (depth < 8) {
         XtSetSensitive (solutiond -> contour_s, False);
         XtSetSensitive (solutiond -> contour_d, False);
 
