@@ -2,6 +2,7 @@
 "*control*SimpleMenu*font:			*new century schoolbook-medium-r-normal-*-14*",
 "*Dialog*font:					*new century schoolbook-medium-r-normal-*-14*",
 "*Command*font:					*new century schoolbook-medium-r-normal-*-14*",
+"*Toggle*font:					*new century schoolbook-medium-r-normal-*-14*",
 "*Label*font:					*new century schoolbook-medium-r-normal-*-14*",
 "*entryShell*font:				*new century schoolbook-medium-r-normal-*-14*",
 "*listShell*font:				*new century schoolbook-medium-r-normal-*-14*",
@@ -39,6 +40,8 @@
 "*TopLevelShell*borderColor:			#000080",
 "*TopLevelShell*Command*background:		#d3d3d3",
 "*TopLevelShell*Command*foreground:		#000080",
+"*TopLevelShell*Toggle*background:		#d3d3d3",
+"*TopLevelShell*Toggle*foreground:		#000080",
 "*control*foreground:				#000080",
 "*control*background:				white",
 "*control.background:				#a9a9a9",
@@ -208,7 +211,6 @@
 "*displShell.layout.borderColor:			Black",
 "*displShell.layout*borderWidth:			0",
 "*displShell.layout*highlightThickness:		0",
-"*stressShell*dw.background:			white",
 "*stressShell.layout.borderColor:		Black",
 "*stressShell.layout*borderWidth:		0",
 "*stressShell.layout*highlightThickness:		0",
